============
Installation
============

Runcrate has not been released yet. To install, you have to clone the GitHub repository::

  git clone https://github.com/ResearchObject/runcrate
  cd runcrate
  pip install .
